@@ -11,13 +11,11 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 from urllib.parse import unquote
 
 import attr
-import docker
 import factory
 import faker
 import pytest
 import requests
 import ruamel.yaml
-from docker.errors import NotFound as ContainerNotFound
 from ldap3 import AUTO_BIND_TLS_BEFORE_BIND, SIMPLE, Connection, Server
 from ldap3.core.exceptions import LDAPInvalidDnError
 from ldap3.utils.dn import parse_dn
@@ -34,7 +32,6 @@ except ImportError as exc:  # pragma: no cover
     ) from exc
 
 
-TEST_DOCKER_CONTAINER_NAME = "udm_rest_only"
 TEST_SERVER_YAML_FILENAME = Path(__file__).parent / "test_server.yaml"
 UDMServer = namedtuple("UDMServer", ["host", "username", "user_dn", "password"])
 fake = faker.Faker()
@@ -59,36 +56,6 @@ class NoTestServerConfig(Exception):
     ...
 
 
-def running_test_container() -> UDMServer:  # pragma: no cover
-    """
-    :raises: ContainerIpUnknown
-    :raises: ContainerNotFound
-    """
-    docker_client = docker.from_env()
-    container = docker_client.containers.get(TEST_DOCKER_CONTAINER_NAME)
-    if container.status != "running":  # pragma: no cover
-        print(
-            f"Found stopped Docker container {TEST_DOCKER_CONTAINER_NAME!r}. Trying to start and continue."
-        )  # pragma: no cover
-        container.start()
-    for k, v in container.attrs["NetworkSettings"]["Networks"].items():
-        try:
-            server = UDMServer(
-                host=v["IPAddress"],
-                username="Administrator",
-                user_dn="uid=Administrator,cn=users,dc=ucs-test,dc=intranet",
-                password="univention",
-            )
-            print(f"Using Docker container '{TEST_DOCKER_CONTAINER_NAME!r}'.")
-            return server
-        except KeyError:  # pragma: no cover
-            pass
-    else:  # pragma: no cover
-        raise ContainerIpUnknown(
-            f"Could not get IP address from container {TEST_DOCKER_CONTAINER_NAME!r}."
-        )
-
-
 @pytest.fixture(scope="session")
 def load_test_server_yaml():
     def _func(path: Union[str, Path] = TEST_SERVER_YAML_FILENAME) -> UDMServer:
@@ -97,7 +64,8 @@ def load_test_server_yaml():
         :raises: TypeError
         """
         with open(path, "r") as fp:
-            config = ruamel.yaml.load(fp, ruamel.yaml.RoundTripLoader)
+            yaml = ruamel.yaml.YAML(typ="rt", pure=True)
+            config = yaml.load(fp)
         return UDMServer(**config)
 
     return _func
@@ -121,7 +89,9 @@ def save_test_server_yaml():
         :raises: OSError (PermissionError etc)
         """
         with open(path, "w") as fp:
-            ruamel.yaml.dump(
+            yaml = ruamel.yaml.YAML(typ="rt", pure=True)
+            yaml.indent = 4
+            yaml.dump(
                 {
                     "host": host,
                     "username": username,
@@ -129,8 +99,6 @@ def save_test_server_yaml():
                     "password": password,
                 },
                 fp,
-                ruamel.yaml.RoundTripDumper,
-                indent=4,
             )
 
     return _func
@@ -173,23 +141,7 @@ def test_server_configuration(load_test_server_yaml) -> UDMServer:  # noqa: C901
         print("OK: Using configuration in YAML file.")
         return res
 
-    print(f"Trying to use running Docker container {TEST_DOCKER_CONTAINER_NAME!r}...")
-    try:
-        res = running_test_container()
-        _test_a_server_configuration(res)
-    except ContainerNotFound:
-        print(f"Container not found: {TEST_DOCKER_CONTAINER_NAME}.")
-    except ContainerIpUnknown as exc:
-        raise BadTestServerConfig(str(exc)) from exc
-    except udm_rest_client.exceptions.APICommunicationError as exc:
-        raise BadTestServerConfig(
-            "Error connecting to test server using credentials for Docker "
-            "Docker container {TEST_DOCKER_CONTAINER_NAME!r}: [{exc.status}] {exc!s}"
-        ) from exc
-    else:
-        return res
-
-    print("Trying to use load test server config from environment...")
+    print("Trying to use test server config from environment...")
     try:
         res = UDMServer(
             host=os.environ["UCS_HOST"],
